/*
 * Copyright 2001-2004 (C) MetaStuff, Ltd. All Rights Reserved.
 * 
 * This software is open source. 
 * See the bottom of this file for the licence.
 * 
 * $Id: LargeDocumentDemo.java,v 1.4 2005/01/29 14:52:57 maartenc Exp $
 */

package org.dom4j.samples;

import org.dom4j.Document;
import org.dom4j.Element;
import org.dom4j.ElementHandler;
import org.dom4j.ElementPath;
import org.dom4j.io.SAXReader;

/**
 * This sample parses a big document using the pruning option of the
 * {@link SAXReader}.
 * 
 * @author <a href="mailto:james.strachan@metastuff.com">James Strachan </a>
 * @version $Revision: 1.4 $
 */
public class LargeDocumentDemo extends SAXDemo implements ElementHandler {

    protected String pruningPath;

    public static void main(String[] args) {
        run(new LargeDocumentDemo(), args);
    }

    public LargeDocumentDemo() {
    }

    public void run(String[] args) throws Exception {
        if (args.length < 2) {
            printUsage("<XML document URL> <pruningPath>");
            return;
        }

        String xmlFile = args[0];
        pruningPath = args[1];

        Document document = parse(xmlFile);
        process(document);
    }

    // ElementHandler interface
    public void onStart(ElementPath path) {
        Element element = path.getCurrent();
        println("onStart: of parsing element: " + element);
    }

    public void onEnd(ElementPath path) {
        Element element = path.getCurrent();

        println("onEnd: of parsing element: " + element + " with: "
                + element.content().size() + " content node(s)");

        // now prune the current element to reduce memory
        element.detach();
    }

    protected Document parse(String url) throws Exception {
        SAXReader reader = new SAXReader();

        println("Parsing document:   " + url);
        println("Using Pruning Path: " + pruningPath);

        // enable pruning to call me back as each Element is complete
        reader.addHandler(pruningPath, this);

        println("##### starting parse");
        Document document = reader.read(url);
        println("##### finished parse");

        // the document will be complete but have the prunePath elements pruned
        println("Now lets dump what is left of the document after pruning...");

        return document;
    }
}

/*
 * Redistribution and use of this software and associated documentation
 * ("Software"), with or without modification, are permitted provided that the
 * following conditions are met:
 * 
 * 1. Redistributions of source code must retain copyright statements and
 * notices. Redistributions must also contain a copy of this document.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 * 
 * 3. The name "DOM4J" must not be used to endorse or promote products derived
 * from this Software without prior written permission of MetaStuff, Ltd. For
 * written permission, please contact dom4j-info@metastuff.com.
 * 
 * 4. Products derived from this Software may not be called "DOM4J" nor may
 * "DOM4J" appear in their names without prior written permission of MetaStuff,
 * Ltd. DOM4J is a registered trademark of MetaStuff, Ltd.
 * 
 * 5. Due credit should be given to the DOM4J Project - http://www.dom4j.org
 * 
 * THIS SOFTWARE IS PROVIDED BY METASTUFF, LTD. AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL METASTUFF, LTD. OR ITS CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 * 
 * Copyright 2001-2004 (C) MetaStuff, Ltd. All Rights Reserved.
 * 
 * $Id: LargeDocumentDemo.java,v 1.4 2005/01/29 14:52:57 maartenc Exp $
 */
